@@ -145,7 +145,7 @@ i_readbmp_wiol(io_glue *ig, int allow_incomplete) {
 	  (int)size_image, (int)xres, (int)yres, (int)clr_used, 
           (int)clr_important));
 
-  if (!i_int_check_image_file_limits(xsize, abs(ysize), 3, sizeof(i_sample_t))) {
+  if (!i_int_check_image_file_limits(xsize, abs((int)ysize), 3, sizeof(i_sample_t))) {
     im_log((aIMCTX, 1, "i_readbmp_wiol: image size exceeds limits\n"));
     return NULL;
   }
@@ -239,7 +239,7 @@ read_packed(io_glue *ig, char *format, ...) {
     switch (code) {
     case 'v':
       if (i_io_read(ig, buf, 2) != 2)
-	return 0;
+	goto fail;
       work = buf[0] + ((i_packed_t)buf[1] << 8);
       if (shrieking)
 	*p = (work ^ SIGNBIT16) - SIGNBIT16;
@@ -249,7 +249,7 @@ read_packed(io_glue *ig, char *format, ...) {
 
     case 'V':
       if (i_io_read(ig, buf, 4) != 4)
-	return 0;
+	goto fail;
       work = buf[0] + (buf[1] << 8) + ((i_packed_t)buf[2] << 16) + ((i_packed_t)buf[3] << 24);
       if (shrieking)
 	*p = (work ^ SIGNBIT32) - SIGNBIT32;
@@ -259,19 +259,19 @@ read_packed(io_glue *ig, char *format, ...) {
 
     case 'C':
       if (i_io_read(ig, buf, 1) != 1)
-	return 0;
+	goto fail;
       *p = buf[0];
       break;
 
     case 'c':
       if (i_io_read(ig, buf, 1) != 1)
-	return 0;
+	goto fail;
       *p = (char)buf[0];
       break;
       
     case '3': /* extension - 24-bit number */
       if (i_io_read(ig, buf, 3) != 3)
-        return 0;
+        goto fail;
       *p = buf[0] + (buf[1] << 8) + ((i_packed_t)buf[2] << 16);
       break;
       
@@ -282,7 +282,12 @@ read_packed(io_glue *ig, char *format, ...) {
       }
     }
   }
+  va_end(ap);
   return 1;
+
+ fail:
+  va_end(ap);
+  return 0;
 }
 
 /*
@@ -311,7 +316,7 @@ write_packed(io_glue *ig, char *format, ...) {
       buf[0] = i & 255;
       buf[1] = i / 256;
       if (i_io_write(ig, buf, 2) == -1)
-	return 0;
+	goto fail;
       break;
 
     case 'V':
@@ -320,14 +325,14 @@ write_packed(io_glue *ig, char *format, ...) {
       buf[2] = (i >> 16) & 0xFF;
       buf[3] = (i >> 24) & 0xFF;
       if (i_io_write(ig, buf, 4) == -1)
-	return 0;
+	goto fail;
       break;
 
     case 'C':
     case 'c':
       buf[0] = i & 0xFF;
       if (i_io_write(ig, buf, 1) == -1)
-	return 0;
+	goto fail;
       break;
 
     default:
@@ -341,6 +346,10 @@ write_packed(io_glue *ig, char *format, ...) {
   va_end(ap);
 
   return 1;
+
+ fail:
+  va_end(ap);
+  return 0;
 }
 
 /*
@@ -741,7 +750,7 @@ read_1bit_bmp(io_glue *ig, int xsize, int ysize, int clr_used,
     return NULL;
   }
 
-  if (xsize + 8 < xsize) { /* if there was overflow */
+  if ((i_img_dim)((i_img_dim_u)xsize + 8) < xsize) { /* if there was overflow */
     /* we check with 8 because we allocate that much for the decoded 
        line buffer */
     i_push_error(0, "integer overflow during memory allocation");
@@ -1342,7 +1351,7 @@ read_direct_bmp(io_glue *ig, int xsize, int ysize, int bit_count,
   long base_offset = FILEHEAD_SIZE + INFOHEAD_SIZE;
   dIMCTXio(ig);
   
-  unpack_code[0] = *("v3V"+pix_size-2);
+  unpack_code[0] = "v3V"[pix_size-2];
   unpack_code[1] = '\0';
 
   line_size = (line_size+3) / 4 * 4;
@@ -1433,7 +1442,7 @@ read_direct_bmp(io_glue *ig, int xsize, int ysize, int bit_count,
     }
   }
   
-  im = i_img_empty(NULL, xsize, ysize);
+  im = i_img_8_new(xsize, ysize, 3);
   if (!im)
     return NULL;
 
