@@ -757,74 +757,6 @@ im_align_size(size_t align, size_t size) {
   }
 }
 
-/*
-=item im_aligned_alloc_low(C<align>, C<size>)
-
-Low level function to allocate aligned memory.
-
-This will use malloc() and returned unaligned memory if no aligned
-allocation function was found during configuration.
-
-C<align> must be a power of two.
-
-C<size> may be rounded up to a multiple of C<align>.
-
-This may return NULL on failure.
-
-=cut
-*/
-
-IMAGER_STATIC_INLINE void *
-im_aligned_alloc_low(size_t align, size_t size) {
-  size_t aligned_size = im_align_size(align, size);
-  IM_ALIGNED_ALLOC_TYPE;
-#if IM_ALIGNED_ALLOC_TYPE == IM_ALIGNED_ALLOC_C11
-  /* posix_memalign() requires that the alignment be at least sizeof(void *),
-     and aligned_alloc() may inherit that requirement
-  */
-  if (align < sizeof(void *)) {
-    return malloc(aligned_size);
-  }
-
-  return aligned_alloc(align, aligned_size);
-#elif IM_ALIGNED_ALLOC_TYPE == IM_ALIGNED_ALLOC_POSIX
-  /* posix_memalign() requires that the alignment be at least sizeof(void *) */
-  if (align < sizeof(void *)) {
-    return malloc(size);
-  }
-
-  void *p;
-  if (posix_memalign(&p, align, aligned_size) != 0)
-    return NULL;
-
-  return p;
-#elif IM_ALIGNED_ALLOC_TYPE == IM_ALIGNED_ALLOC_MSVC
-  return _aligned_malloc(aligned_size, align);
-#else
-  return malloc(aligned_size);
-#endif
-}
-
-/*
-=item im_aligned_free(C<p>)
-
-Free a block of memory allocated with im_aligned_alloc_low().
-
-=cut
-*/
-
-IMAGER_STATIC_INLINE void
-im_aligned_free(void *p) {
-#if IM_ALIGNED_ALLOC_TYPE == IM_ALIGNED_ALLOC_C11 || \
-    IM_ALIGNED_ALLOC_TYPE == IM_ALIGNED_ALLOC_POSIX
-  free(p);
-#elif IM_ALIGNED_ALLOC_TYPE == IM_ALIGNED_ALLOC_MSVC
-  _aligned_free(p);
-#else
-  return free(p);
-#endif
-}
-
 /*
 =item im_aligned_alloc_fatal(align, size)
 
