@@ -11,15 +11,10 @@
 #define DTBUFF 50
 #define DATABUFF DTBUFF+3+10+1+5+1+1
 
-#if 0
-static int   log_level   = 0;
-static FILE *lg_file     = NULL;
-static char  date_buffer[DTBUFF];
-static char  data_buffer[DATABUFF];
-#endif
-
 #define LOG_DATE_FORMAT "%Y/%m/%d %H:%M:%S"
 
+static i_mutex_t log_mutex;
+
 static void
 im_vloog(pIMCTX, int level, const char *fmt, va_list ap);
 
@@ -30,21 +25,34 @@ im_vloog(pIMCTX, int level, const char *fmt, va_list ap);
 int
 im_init_log(pIMCTX, const char* name,int level) {
   i_clear_error();
+
+  if (!log_mutex) {
+    log_mutex = i_mutex_new();
+  }
+
+  if (aIMCTX->lg_file) {
+    if (aIMCTX->own_log)
+      fclose(aIMCTX->lg_file);
+    aIMCTX->lg_file = NULL;
+  }
+  
   aIMCTX->log_level = level;
   if (level < 0) {
     aIMCTX->lg_file = NULL;
   } else {
     if (name == NULL) {
       aIMCTX->lg_file = stderr;
+      aIMCTX->own_log = 0;
     } else {
       if (NULL == (aIMCTX->lg_file = fopen(name, "w+")) ) { 
 	im_push_errorf(aIMCTX, errno, "Cannot open file '%s': (%d)", name, errno);
 	return 0;
       }
+      aIMCTX->own_log = 1;
+      setvbuf(aIMCTX->lg_file, NULL, _IONBF, BUFSIZ);
     }
   }
   if (aIMCTX->lg_file) {
-    setvbuf(aIMCTX->lg_file, NULL, _IONBF, BUFSIZ);
     im_log((aIMCTX, 0,"Imager - log started (level = %d)\n", level));
   }
 
@@ -73,7 +81,12 @@ im_fatal(pIMCTX, int exitcode,const char *fmt, ... ) {
     im_vloog(aIMCTX, 0, fmt, ap);
     va_end(ap);
   }
-  exit(exitcode);
+  va_start(ap, fmt);
+  vfprintf(stderr, fmt, ap);
+  fputc('\n', stderr);
+  va_end(ap);
+  
+  abort();
 }
 
 /*
@@ -91,8 +104,10 @@ im_vloog(pIMCTX, int level, const char *fmt, va_list ap) {
   struct tm *str_tm;
   char date_buffer[DTBUFF];
 
-  if (!aIMCTX->lg_file || level > aIMCTX->log_level)
+  if (!aIMCTX || !aIMCTX->lg_file || level > aIMCTX->log_level)
     return;
+
+  i_mutex_lock(log_mutex);
   
   timi = time(NULL);
   str_tm = localtime(&timi);
@@ -101,6 +116,8 @@ im_vloog(pIMCTX, int level, const char *fmt, va_list ap) {
 	  aIMCTX->filename, aIMCTX->line, level);
   vfprintf(aIMCTX->lg_file, fmt, ap);
   fflush(aIMCTX->lg_file);
+
+  i_mutex_unlock(log_mutex);
 }
 
 void
@@ -108,7 +125,7 @@ i_loog(int level,const char *fmt, ... ) {
   dIMCTX;
   va_list ap;
 
-  if (!aIMCTX->lg_file || level > aIMCTX->log_level)
+  if (!aIMCTX || !aIMCTX->lg_file || level > aIMCTX->log_level)
     return;
 
   va_start(ap,fmt);
@@ -120,7 +137,7 @@ void
 im_loog(pIMCTX, int level,const char *fmt, ... ) {
   va_list ap;
 
-  if (!aIMCTX->lg_file || level > aIMCTX->log_level)
+  if (!aIMCTX || !aIMCTX->lg_file || level > aIMCTX->log_level)
     return;
 
   va_start(ap,fmt);
@@ -139,7 +156,7 @@ This is an internal function called by the mm_log() macro.
 
 void
 im_lhead(pIMCTX, const char *file, int line) {
-  if (aIMCTX->lg_file != NULL) {
+  if (aIMCTX && aIMCTX->lg_file != NULL) {
     aIMCTX->filename = file;
     aIMCTX->line = line;
   }
@@ -157,7 +174,7 @@ void i_lhead(const char *file, int line) {
  * Logging is inactive - insert dummy functions
  */
 
-int i_init_log(const char* name,int onoff) {
+int im_init_log(pIMCTX, const char* name,int onoff) {
   i_clear_error();
   i_push_error(0, "Logging disabled");
   return 0;
@@ -170,7 +187,14 @@ void
 i_loog(int level,const char *fmt, ... ) {
 }
 
+void
+im_loog(pIMCTX, int level,const char *fmt, ... ) {
+}
+
 void
 i_lhead(const char *file, int line) { }
 
+void
+im_lhead(pIMCTX, const char *file, int line) { }
+
 #endif
